pub enum ChangedContentVisitOutcome {
Visited(Box<ChangedContentVisitReport>),
FullRescanRequired,
}Expand description
Result of attempting a traversal-free watcher content visit.
Variants
Visited(Box<ChangedContentVisitReport>)
Only changed file paths were matched, opened, and visited.
FullRescanRequired
The plan can affect directory structure or selection and therefore requires the caller to perform a complete scan.