pub enum DeltaQuality {
ContentHash,
Metadata,
Partial,
}Expand description
Strength of the evidence used to classify a scan delta.
Variants
ContentHash
Both complete reports contain a content hash for every selected file.
Metadata
At least one file was compared by size because a content hash was absent.
Partial
At least one report is partial or terminated.