pub struct PortableScanReport {
pub files: Vec<PortableScannedFile>,
pub skipped: Vec<PortableSkippedEntry>,
pub warnings: Vec<PortableScanWarning>,
pub ignore_sources: Vec<PortableIgnoreSourceEvidence>,
pub revision: String,
pub complete: bool,
pub termination: Option<ScanTermination>,
pub selection_portable: bool,
}Expand description
A deterministic report suitable for crossing a repository or process boundary.
Absolute roots, absolute file paths, file identities, timestamps, cache statistics, and free-form diagnostic text are intentionally omitted.
Fields
files: Vec<PortableScannedFile>skipped: Vec<PortableSkippedEntry>warnings: Vec<PortableScanWarning>ignore_sources: Vec<PortableIgnoreSourceEvidence>revision: Stringcomplete: booltermination: Option<ScanTermination>selection_portable: boolWhether selection itself was independent of host-level Git configuration.