pub struct WatcherEventAdapter { /* private fields */ }Expand description
Converts watcher-specific path notifications into scanner cache work.
Implementations
Sourceimpl WatcherEventAdapter
impl WatcherEventAdapter
Sourcepub fn new<I, S>(root: impl AsRef<Path>, ignore_files: I) -> Result<Self>
pub fn new<I, S>(root: impl AsRef<Path>, ignore_files: I) -> Result<Self>
Creates an adapter for an existing repository root.
Errors
Returns an error when the root cannot be canonicalized or is not a directory.
Sourcepub fn with_options(
root: impl AsRef<Path>,
options: &ScanOptions,
) -> Result<Self>
pub fn with_options( root: impl AsRef<Path>, options: &ScanOptions, ) -> Result<Self>
Sourcepub fn plan<I>(&self, events: I) -> WatchPlanwhere
I: IntoIterator<Item = WatchEvent>,
pub fn plan<I>(&self, events: I) -> WatchPlanwhere
I: IntoIterator<Item = WatchEvent>,
Coalesces raw watcher events into a stable scanner invalidation plan.